#[repr(C)]pub struct PamMessage {
pub msg_style: c_int,
pub msg: *const c_char,
}Expand description
Message struct to transfer authentication data to the user
From _pam_types.h:
“Used to pass prompting text, error messages, or other informatory text to the user. This structure is allocated and freed by the PAM library (or loaded module).”
Fields
msg_style: c_intmsg: *const c_charTrait Implementations
Sourceimpl Clone for PamMessage
impl Clone for PamMessage
Sourcefn clone(&self) -> PamMessage
fn clone(&self) -> PamMessage
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PamMessage
impl Debug for PamMessage
impl Copy for PamMessage