pub enum PamItemType {
Show 13 variants
SERVICE = 1,
USER = 2,
TTY = 3,
RHOST = 4,
CONV = 5,
AUTHTOK = 6,
OLDAUTHTOK = 7,
RUSER = 8,
USER_PROMPT = 9,
FAIL_DELAY = 10,
XDISPLAY = 11,
XAUTHDATA = 12,
AUTHTOK_TYPE = 13,
}Expand description
The Linux-PAM item types
These defines are used by pam_set_item() and pam_get_item().
Please check the spec which are allowed for use by applications
and which are only allowed for use by modules.
Variants
SERVICE = 1
The service name
USER = 2
The user name
TTY = 3
The tty name
RHOST = 4
The remote host name
CONV = 5
The pam_conv structure
AUTHTOK = 6
The authentication token (password)
OLDAUTHTOK = 7
The old authentication token
RUSER = 8
The remote user name
USER_PROMPT = 9
the prompt for getting a username Linux-PAM extensions
FAIL_DELAY = 10
app supplied function to override failure delays
XDISPLAY = 11
X display name
XAUTHDATA = 12
X server authentication data
AUTHTOK_TYPE = 13
The type for pam_get_authtok